@@ -162,13 +162,13 @@ void Controller::playVideo(const QString &url) {
     emit playbackStarted();
 #endif
 
-#ifdef Q_WS_X11
-    QStringList args;
-    args << "-cache" << "4096" << "-fs" << url;
-    QProcess *player = new QProcess();
-    connect(player, SIGNAL(finished(int, QProcess::ExitStatus)), player, SLOT(deleteLater()));
-    player->start("/usr/bin/mplayer", args);
-#endif
+//#ifdef Q_WS_X11
+//    QStringList args;
+//    args << "-cache" << "4096" << "-fs" << url;
+//    QProcess *player = new QProcess();
+//    connect(player, SIGNAL(finished(int, QProcess::ExitStatus)), player, SLOT(deleteLater()));
+//    player->start("/usr/bin/mplayer", args);
+//#endif
 }
 
 void Controller::deleteVideo(const QString &path) {
