@@ -28,9 +28,13 @@
         <translation type="obsolete">cuteTube-QML - 0.5.1 in deutsch</translation>
     </message>
     <message>
-        <location filename="../AboutDialog.qml" line="44"/>
         <source>cuteTube-QML - 0.6.1</source>
-        <translation>cuteTube-QML - 0.6.1 in deutsch</translation>
+        <translation type="obsolete">cuteTube-QML - 0.6.1 in deutsch</translation>
+    </message>
+    <message>
+        <location filename="../AboutDialog.qml" line="44"/>
+        <source>cuteTube-QML - 0.6.3</source>
+        <translation>cuteTube-QML - 0.6.3 in deutsch</translation>
     </message>
     <message>
         <location filename="../AboutDialog.qml" line="56"/>
@@ -219,42 +223,52 @@
 <context>
     <name>Controller</name>
     <message>
-        <location filename="../../../controller.cpp" line="45"/>
+        <location filename="../../../controller.cpp" line="46"/>
         <source>English</source>
         <translation>Englisch</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="46"/>
+        <location filename="../../../controller.cpp" line="47"/>
         <source>German</source>
         <translation>Deutsch</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="47"/>
+        <location filename="../../../controller.cpp" line="48"/>
         <source>Italian</source>
         <translation>Italienisch</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="48"/>
+        <location filename="../../../controller.cpp" line="49"/>
         <source>Finnish</source>
         <translation>Finnisch</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="168"/>
+        <location filename="../../../controller.cpp" line="50"/>
+        <source>Dutch</source>
+        <translation>Niederländisch</translation>
+    </message>
+    <message>
+        <location filename="../../../controller.cpp" line="51"/>
+        <source>Polish</source>
+        <translation>Polnisch</translation>
+    </message>
+    <message>
+        <location filename="../../../controller.cpp" line="177"/>
         <source>Video deleted from device</source>
         <translation>Video vom Gerät gelöscht</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="171"/>
+        <location filename="../../../controller.cpp" line="180"/>
         <source>Unable to delete video</source>
         <translation>Löschen des Videos nicht möglich</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="175"/>
+        <location filename="../../../controller.cpp" line="184"/>
         <source>Video not found</source>
         <translation>Video nicht gefunden</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="230"/>
+        <location filename="../../../controller.cpp" line="239"/>
         <source>Copied to clipboard</source>
         <translation>In Zwischenablage kopiert</translation>
     </message>
@@ -592,17 +606,17 @@
 <context>
     <name>SettingsDialog</name>
     <message>
-        <location filename="../SettingsDialog.qml" line="143"/>
+        <location filename="../SettingsDialog.qml" line="144"/>
         <source>Your saved searches have been cleared</source>
         <translation>Die gespeicherten Suchen wurden gelöscht</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="146"/>
+        <location filename="../SettingsDialog.qml" line="147"/>
         <source>Database error. Unable to clear searches</source>
         <translation>Datenbankfehler. Konnte Konto nicht speichern</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="195"/>
+        <location filename="../SettingsDialog.qml" line="196"/>
         <source>Settings</source>
         <translation>Optionen</translation>
     </message>
@@ -637,39 +651,38 @@
         <translation>Media Player</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="134"/>
+        <location filename="../SettingsDialog.qml" line="135"/>
         <location filename="../SettingsDialog.qml" line="294"/>
         <location filename="../SettingsDialog.qml" line="466"/>
         <source>Language</source>
         <translation>Sprache</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="110"/>
+        <location filename="../SettingsDialog.qml" line="111"/>
         <location filename="../SettingsDialog.qml" line="320"/>
         <source>Playback Quality</source>
         <translation>Wiedergabequalität</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="113"/>
+        <location filename="../SettingsDialog.qml" line="114"/>
         <location filename="../SettingsDialog.qml" line="338"/>
         <source>Download Quality</source>
         <translation>Downloadqualität</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="116"/>
+        <location filename="../SettingsDialog.qml" line="117"/>
         <location filename="../SettingsDialog.qml" line="356"/>
         <source>Start Downloads</source>
         <translation>Downloads starten</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="125"/>
+        <location filename="../SettingsDialog.qml" line="126"/>
         <location filename="../SettingsDialog.qml" line="412"/>
         <source>Screen Orientation</source>
         <translation>Bildschirmausrichtung</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="22"/>
-        <location filename="../SettingsDialog.qml" line="128"/>
+        <location filename="../SettingsDialog.qml" line="129"/>
         <location filename="../SettingsDialog.qml" line="430"/>
         <source>Media Player</source>
         <translation>Media Player</translation>
@@ -688,27 +701,27 @@
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="19"/>
-        <location filename="../SettingsDialog.qml" line="38"/>
-        <location filename="../SettingsDialog.qml" line="71"/>
+        <location filename="../SettingsDialog.qml" line="39"/>
+        <location filename="../SettingsDialog.qml" line="72"/>
         <source>Automatically</source>
         <translation>Automatisch</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="19"/>
-        <location filename="../SettingsDialog.qml" line="41"/>
+        <location filename="../SettingsDialog.qml" line="42"/>
         <source>Manually</source>
         <translation>Manuell</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="20"/>
-        <location filename="../SettingsDialog.qml" line="45"/>
-        <location filename="../SettingsDialog.qml" line="77"/>
+        <location filename="../SettingsDialog.qml" line="46"/>
+        <location filename="../SettingsDialog.qml" line="78"/>
         <source>On</source>
         <translation>Auf</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="20"/>
-        <location filename="../SettingsDialog.qml" line="48"/>
+        <location filename="../SettingsDialog.qml" line="49"/>
         <source>Off</source>
         <translation>Off</translation>
     </message>
@@ -758,41 +771,51 @@
         <translation>Italienisch</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="37"/>
-        <location filename="../SettingsDialog.qml" line="72"/>
+        <location filename="../SettingsDialog.qml" line="24"/>
+        <source>Dutch</source>
+        <translation>Niederländisch</translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="24"/>
+        <source>Polish</source>
+        <translation>Polnisch</translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="38"/>
+        <location filename="../SettingsDialog.qml" line="73"/>
         <source>Queued</source>
         <translation>in Warteschlange</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="75"/>
+        <location filename="../SettingsDialog.qml" line="76"/>
         <source>Paused</source>
         <translation>Pausiert</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="84"/>
+        <location filename="../SettingsDialog.qml" line="85"/>
         <source>Your settings have been saved</source>
         <translation>Ihre Einstellungen wurden gespeichert</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="89"/>
-        <location filename="../SettingsDialog.qml" line="119"/>
+        <location filename="../SettingsDialog.qml" line="90"/>
+        <location filename="../SettingsDialog.qml" line="120"/>
         <source>Download Path</source>
         <translation>Downloadverzeichnis</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="91"/>
+        <location filename="../SettingsDialog.qml" line="92"/>
         <source>Download Location</source>
         <translation>Downloadverzeichnis</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="122"/>
+        <location filename="../SettingsDialog.qml" line="123"/>
         <location filename="../SettingsDialog.qml" line="261"/>
         <location filename="../SettingsDialog.qml" line="394"/>
         <source>Safe Search</source>
         <translation>Sicher Suchlauf</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="131"/>
+        <location filename="../SettingsDialog.qml" line="132"/>
         <location filename="../SettingsDialog.qml" line="285"/>
         <location filename="../SettingsDialog.qml" line="448"/>
         <source>Theme</source>
@@ -1261,7 +1284,7 @@
         <translation type="obsolete">Fehler: Kann Video nicht empfangen</translation>
     </message>
     <message>
-        <location filename="../Widget.qml" line="271"/>
+        <location filename="../Widget.qml" line="287"/>
         <source>No videos found</source>
         <translation>Keine Videos gefunden</translation>
     </message>
@@ -1364,34 +1387,34 @@
         <translation>Bei YouTube angemeldet als &apos;</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="120"/>
-        <location filename="../../../youtube.cpp" line="226"/>
+        <location filename="../../../youtube.cpp" line="115"/>
+        <location filename="../../../youtube.cpp" line="221"/>
         <source>Error - Server repsonse is: </source>
         <translation>Fehler - Serverantwort ist:</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="170"/>
-        <location filename="../../../youtube.cpp" line="178"/>
+        <location filename="../../../youtube.cpp" line="165"/>
+        <location filename="../../../youtube.cpp" line="173"/>
         <source>Upload aborted</source>
         <translation>Upload abgebrochen</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="185"/>
+        <location filename="../../../youtube.cpp" line="180"/>
         <source>Upload interrupted. Attempting to resume...</source>
         <translation>Upload unterbrochen. Versuche wiederaufnahme...</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="189"/>
+        <location filename="../../../youtube.cpp" line="184"/>
         <source>Upload failed</source>
         <translation>Upload fehlgeschlagen</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="195"/>
+        <location filename="../../../youtube.cpp" line="190"/>
         <source>Upload is completed</source>
         <translation>Upload ist komplett</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="387"/>
+        <location filename="../../../youtube.cpp" line="382"/>
         <source>Error: Unable to retrieve video</source>
         <translation>Fehler: Kann Video nicht empfangen</translation>
     </message>
@@ -1432,44 +1455,44 @@
         <translation>Video wurde zur Wiedergabeliste hinzugefügt</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="159"/>
+        <location filename="../main.qml" line="160"/>
         <source>New playlist created</source>
         <translation>Neue Wiedergabeliste erstellt</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="199"/>
+        <location filename="../main.qml" line="200"/>
         <source>Converting</source>
         <translation>Konvertiere</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="208"/>
+        <location filename="../main.qml" line="209"/>
         <source>Conversion of &apos;</source>
         <translation>Unterhaltung zwischen &apos;</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="208"/>
+        <location filename="../main.qml" line="209"/>
         <source>&apos; failed</source>
         <translation>&apos; gescheitert</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="222"/>
-        <location filename="../main.qml" line="229"/>
-        <location filename="../main.qml" line="269"/>
+        <location filename="../main.qml" line="223"/>
+        <location filename="../main.qml" line="230"/>
+        <location filename="../main.qml" line="270"/>
         <source>Queued</source>
         <translation>in Warteschlange</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="237"/>
+        <location filename="../main.qml" line="238"/>
         <source>Paused</source>
         <translation>Pausiert</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="414"/>
+        <location filename="../main.qml" line="415"/>
         <source>Most Recent</source>
         <translation>Aktuellste Videos</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="415"/>
+        <location filename="../main.qml" line="416"/>
         <source>Most Viewed</source>
         <translation>Meistgesehen</translation>
     </message>
@@ -1477,9 +1500,8 @@
 <context>
     <name>mainscripts</name>
     <message>
-        <location filename="../scripts/mainscripts.js" line="19"/>
         <source>Media Player</source>
-        <translation>Media Player</translation>
+        <translation type="obsolete">Media Player</translation>
     </message>
     <message>
         <location filename="../scripts/mainscripts.js" line="119"/>
@@ -1561,9 +1583,8 @@
         <translation>Automatisch</translation>
     </message>
     <message>
-        <location filename="../scripts/settings.js" line="132"/>
         <source>Media Player</source>
-        <translation>Media Player</translation>
+        <translation type="obsolete">Media Player</translation>
     </message>
     <message>
         <location filename="../scripts/settings.js" line="133"/>
