@@ -129,7 +129,7 @@ function setDefaultSettings() {
                     [ "downloadPath", "/home/user/MyDocs/.cutetube/" ],
                     [ "safeSearch", "none" ],
                     [ "screenOrientation", qsTr("Automatic") ],
-                    [ "mediaPlayer", qsTr("Media Player") ],
+                    [ "mediaPlayer", "Media Player" ],
                     [ "searchOrder", qsTr("Date") ],
                     [ "theme", qsTr("Dark") ],
                     [ "language", qsTr("English") ] ];
